"""qr2scad package"""
__package__ = 'qr2scad'
__author__ = 'Victor Engmark'
__copyright__ = 'Copyright (C) 2010, 2012-2013 Victor Engmark'
__credits__ = ['Victor Engmark']
__maintainer__ = 'Victor Engmark'
__email__ = 'victor.engmark@gmail.com'
__license__ = 'GPL v3 or newer'
__url__ = 'https://github.com/l0b0/' + __package__
__version__ = '0.7.2'
